function [regData] = climateSpace_region(data,Z,Z_precip,Z_tavg,...
    figNum,subPlotID,c_bar)
% climateSpace.m Plot data in global climate space
%   Detailed explanation goes here

%% Extract Data
site_climate = data.site_climate;
legend_text = data.legend_text;
x_label = data.x_label;
y_label = data.y_label;
plot_title = data.plot_title;
bins = data.bins;
col = data.col;
regCol = data.regCol;
[X Y] = meshgrid(data.x,data.y);
X = X'; Y = Y';

regName = data.regName;
latReg = data.latReg;
lonReg = data.lonReg;
col = data.col;

if nargin < 7
    c_bar = 1;
end
if length(subPlotID) > 1
    subPlotID =...
        [num2str(subPlotID(1)) num2str(subPlotID(2)) num2str(subPlotID(3))];
end
%%
meanMaxT = max(Z_tavg,[],3);  % [deg. C] Maxiumn mean annual temperature
% in = find(meanMaxT > -9999);

totAnnP = sum(Z_precip,3);  % [mm] Total annual precipitation
% in2 = find(totAnnP > -9999);
% 
in3 = find(Z > -9999);  

z = Z(in3);                 % Input variable, to scale z by
x = meanMaxT(in3);
y = totAnnP(in3);


%% Plot climate gradient
if figNum
    figure(figNum);
    set(gcf,'color','w')
end 
if subPlotID
    if length(subPlotID) > 3
        subplot(5,2,10)
    else
        subplot(subPlotID)
    end
end

for i = 1:length(bins)
    if i == 1;
        in = find(z<=bins(i));
    else
        in = find([z <= bins(i)] .* [z > bins(i-1)]);
    end
    plot(x(in),y(in),'s','markerfacecolor',col(i,:),...
        'markeredgecolor',col(i,:),'markersize',2)
    if i == 1; hold on; end
end

if c_bar == 1
    cbar_axes = colorbar('YTick',[1:length(bins)+1],'YTickLabel',legend_text);
    colormap(gca,col)
    cbfreeze
end

xlabel(x_label)
ylabel(y_label)
title(plot_title)
set(gca,'fontsize',10,'yscale','log')

%% Add region-specific data
for j = 1:length(regName)
    lat = latReg(j,:);
    lon = lonReg(j,:);
    temp = ([(Y <= lat(2)) .*...
        (Y > lat(1)) .*...
        (X <= lon(2)) .*...
        (X > lon(1))]);
    locIn = find(temp == 1);
    plot(meanMaxT(locIn),totAnnP(locIn),'sk',...
    'markerfacecolor',[0.6 0.6 0.6],'markeredgecolor',[0.6 0.6 0.6],...
    'markersize',4) 
%     reg_NPP(j,:) = [min(Z(locIn)) max(Z(locIn))]
    reg_T(j,:) = [min(meanMaxT(locIn)) max(meanMaxT(locIn))];
    reg_P(j,:) = [min(totAnnP(locIn)) max(totAnnP(locIn))];
end  

regData = [reg_T; reg_P];

%% Add site-specific data
hold on

for j = 1:length(regName)
    lat = latReg(j,:);
    lon = lonReg(j,:);
    temp = sum([(site_climate(:,1) <= lat(2)) +...
        (site_climate(:,1) > lat(1)) +...
        (site_climate(:,2) <= lon(2)) +...
        (site_climate(:,2) > lon(1))],2);
    locIn = find(temp == 4);
    % x = mean temp. of warmest month, y = total annual precip.
    plot(site_climate(locIn,3),site_climate(locIn,4),'.k',...
    'markersize',10)
%     'markerfacecolor',regCol(j,:),'markeredgecolor',regCol(j,:),...

end
% legend([legend_text 'GPFD' regName],'Location','BestOutside')
% legend([legend_text],'Location','BestOutside')
set(gca,'color',[0.9 0.9 0.9],'fontsize',10)
